<?php

/**
 * This is the model class for table "maf_message".
 *
 * The followings are the available columns in table 'maf_message':
 * @property string $itemid
 * @property string $title
 * @property string $style
 * @property integer $typeid
 * @property string $content
 * @property string $fromuser
 * @property string $touser
 * @property string $addtime
 * @property string $ip
 * @property integer $isread
 * @property integer $issend
 * @property integer $feedback
 * @property integer $status
 * @property string $groupids
 */
class AdminMessage extends CActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'maf_message';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('content', 'required'),
			array('typeid, isread, issend, feedback, status', 'numerical', 'integerOnly'=>true),
			array('title', 'length', 'max'=>100),
			array('style, ip', 'length', 'max'=>50),
			array('fromuser, touser', 'length', 'max'=>30),
			array('addtime', 'length', 'max'=>10),
			array('groupids', 'length', 'max'=>20),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('itemid, title, style, typeid, content, fromuser, touser, addtime, ip, isread, issend, feedback, status, groupids', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'itemid' => 'Itemid',
			'title' => 'Title',
			'style' => 'Style',
			'typeid' => 'Typeid',
			'content' => 'Content',
			'fromuser' => 'Fromuser',
			'touser' => 'Touser',
			'addtime' => 'Addtime',
			'ip' => 'Ip',
			'isread' => 'Isread',
			'issend' => 'Issend',
			'feedback' => 'Feedback',
			'status' => 'Status',
			'groupids' => 'Groupids',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('itemid',$this->itemid,true);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('style',$this->style,true);
		$criteria->compare('typeid',$this->typeid);
		$criteria->compare('content',$this->content,true);
		$criteria->compare('fromuser',$this->fromuser,true);
		$criteria->compare('touser',$this->touser,true);
		$criteria->compare('addtime',$this->addtime,true);
		$criteria->compare('ip',$this->ip,true);
		$criteria->compare('isread',$this->isread);
		$criteria->compare('issend',$this->issend);
		$criteria->compare('feedback',$this->feedback);
		$criteria->compare('status',$this->status);
		$criteria->compare('groupids',$this->groupids,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return AdminMessage the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
