<?php

/**
 * This is the model class for table "maf_sell".
 *
 * The followings are the available columns in table 'maf_sell':
 * @property string $proid
 * @property string $catid
 * @property string $mycatid
 * @property integer $typeid
 * @property string $areaid
 * @property integer $level
 * @property string $title
 * @property string $style
 * @property string $introduce
 * @property string $brand
 * @property string $unit
 * @property string $price
 * @property double $minamount
 * @property double $amount
 * @property integer $days
 * @property string $tag
 * @property string $keyword
 * @property string $hits
 * @property integer $groupid
 * @property integer $validated
 * @property string $ip
 * @property integer $status
 * @property integer $create_user_id
 * @property string $image
 * @property string $create_time
 * @property string $update_time
 * @property integer $update_user_id
 * @property string $note
 */
class AdminSell extends AdminSell2ActiveRecord
{
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'maf_sell';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('typeid, level, days, groupid, validated, status, create_user_id, update_user_id', 'numerical', 'integerOnly'=>true),
			array('minamount, amount', 'numerical'),
			array('title', 'required'),
			array('catid, areaid, unit, price, hits', 'length', 'max'=>10),
			array('mycatid', 'length', 'max'=>20),
			array('title, brand, tag', 'length', 'max'=>100),
			array('style, ip', 'length', 'max'=>50),
			array('keyword, note', 'length', 'max'=>255),
			array('introduce', 'length', 'max'=>5000),
			array('image', 'length', 'max'=>64),
			
			array('image', 'file', 'allowEmpty'=>true,'types'=>'jpg,jpeg,png,gif,bmp','safe' => false),//wyx01
			array('create_time, update_time', 'safe'),
			// The following rule is used by search().
			// @todo Please remove those attributes that should not be searched.
			array('proid, catid, mycatid, typeid, areaid, level, title, style, introduce, brand, unit, price, minamount, amount, days, tag, keyword, hits, groupid, validated, ip, status, create_user_id, image, create_time, update_time, update_user_id, note', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'proid' => 'Proid',
			'catid' => 'Catid',
			'mycatid' => 'Mycatid',
			'typeid' => 'Typeid',
			'areaid' => 'Areaid',
			'level' => 'Level',
			'title' => 'Product name 产品名称',
			'style' => 'Style 产品型号',
			'introduce' => 'Introduce 产品详情',
			'brand' => 'Brand 品牌',
			'unit' => 'Unit 产品单位',
			'price' => 'Price 价格 $',
			'minamount' => 'Minimum order quantity 最小定购量',
			'amount' => 'Amount',
			'days' => 'Production days 生产时间',
			'tag' => 'Tag',
			'keyword' => 'Keyword 产品关键词',
			'hits' => 'Hits',
			'groupid' => 'Groupid 产品类别',
			'validated' => 'Vali date 价格有效期',
			'ip' => 'Ip',
			'status' => 'Status',
			'create_user_id' => 'Create User',
			'image' => 'Image  产品图片',
			'create_time' => 'Create Time',
			'update_time' => 'Update Time',
			'update_user_id' => 'Update User',
			'note' => 'Note',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 *
	 * Typical usecase:
	 * - Initialize the model fields with values from filter form.
	 * - Execute this method to get CActiveDataProvider instance which will filter
	 * models according to data in model fields.
	 * - Pass data provider to CGridView, CListView or any similar widget.
	 *
	 * @return CActiveDataProvider the data provider that can return the models
	 * based on the search/filter conditions.
	 */
	public function search()
	{
		// @todo Please modify the following code to remove attributes that should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('proid',$this->proid,true);
		$criteria->compare('catid',$this->catid,true);
		$criteria->compare('mycatid',$this->mycatid,true);
		$criteria->compare('typeid',$this->typeid);
		$criteria->compare('areaid',$this->areaid,true);
		$criteria->compare('level',$this->level);
		$criteria->compare('title',$this->title,true);
		$criteria->compare('style',$this->style,true);
		$criteria->compare('introduce',$this->introduce,true);
		$criteria->compare('brand',$this->brand,true);
		$criteria->compare('unit',$this->unit,true);
		$criteria->compare('price',$this->price,true);
		$criteria->compare('minamount',$this->minamount);
		$criteria->compare('amount',$this->amount);
		$criteria->compare('days',$this->days);
		$criteria->compare('tag',$this->tag,true);
		$criteria->compare('keyword',$this->keyword,true);
		$criteria->compare('hits',$this->hits,true);
		$criteria->compare('groupid',$this->groupid);
		$criteria->compare('validated',$this->validated);
		$criteria->compare('ip',$this->ip,true);
		$criteria->compare('status',$this->status);
		$criteria->compare('create_user_id',$this->create_user_id);
		$criteria->compare('image',$this->image);
		$criteria->compare('create_time',$this->create_time,true);
		$criteria->compare('update_time',$this->update_time,true);
		$criteria->compare('update_user_id',$this->update_user_id);
		$criteria->compare('note',$this->note,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}

	/**
	 * Returns the static model of the specified AR class.
	 * Please note that you should have this exact method in all your CActiveRecord descendants!
	 * @param string $className active record class name.
	 * @return AdminSell the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
}
